@@ -19,7 +19,7 @@ import (
 	"errors"
 	"fmt"
 
-	"github.com/appc/spec/Godeps/_workspace/src/k8s.io/kubernetes/pkg/api/resource"
+	"k8s.io/kubernetes/pkg/api/resource"
 )
 
 var (
@@ -85,6 +85,15 @@ func (r ResourceBase) AssertValid() error {
 	return nil
 }
 
+// TODO(lucab): both need to be clarified in spec,
+// see https://github.com/appc/spec/issues/625
+func (l ResourceBase) multipleAllowed() bool {
+	return true
+}
+func (l ResourceBase) Conflicts() []ACIdentifier {
+	return nil
+}
+
 type ResourceBlockBandwidth struct {
 	ResourceBase
 }
